@@ -32,7 +32,7 @@ from datetime import timedelta
 import threading
 import time
 import socket
-import pwd 
+import getpass 
 import os
 import select
 import SocketServer
@@ -281,7 +281,7 @@ class LocalConnection( object ):
     from Pyro.errors import ConnectionClosedError 
     import subprocess
 
-    login = pwd.getpwuid(os.getuid())[0] 
+    login = getpass.getuser()
     pyro_objet_name = "workflow_engine_" + login
 
     # run the workflow engine process and get back the  
