@@ -17,7 +17,7 @@ soma-workflow engine classes
 
 from datetime import date, timedelta, datetime
 import threading
-import pwd
+import getpass
 import os
 import time
 import logging
@@ -144,7 +144,7 @@ class WorkflowEngineLoop(object):
     self._running = False
 
     try:
-      userLogin = pwd.getpwuid(os.getuid())[0] 
+      userLogin = getpass.getuser()
     except Exception, e:
       self.logger.critical("Couldn't identify user %s: %s \n" %(type(e), e))
       raise EngineError("Couldn't identify user %s: %s \n" %(type(e), e))
@@ -422,13 +422,14 @@ class WorkflowEngineLoop(object):
     The jobs to submit after add_job, add_workflow and restart_workflow are 
     first stored in _pending_queues waiting to be submitted.
     '''
-    if engine_job.queue in self._pending_queues:
-      self._pending_queues[engine_job.queue].append(engine_job)
-      self._pending_queues[engine_job.queue].sort(key=lambda job: job.priority, 
-                                                  reverse=True)
-    else:
-      self._pending_queues[engine_job.queue] = [engine_job]
-    engine_job.status = constants.SUBMISSION_PENDING
+    with self._lock:
+      if engine_job.queue in self._pending_queues:
+        self._pending_queues[engine_job.queue].append(engine_job)
+        self._pending_queues[engine_job.queue].sort(key=lambda job: job.priority, 
+                                                    reverse=True)
+      else:
+        self._pending_queues[engine_job.queue] = [engine_job]
+      engine_job.status = constants.SUBMISSION_PENDING
 
 
   def _get_pending_job_to_submit(self):
@@ -514,23 +515,24 @@ class WorkflowEngineLoop(object):
     if job.status == constants.DONE or job.status == constants.FAILED:
       return False
     else:
-      if job.drmaa_id:
-        self.logger.debug("Kill job " + repr(job_id) + " drmaa id: " + repr(job.drmaa_id) + " status " + repr(job.status))
-        try:
-          self._scheduler.kill_job(job.drmaa_id)
-        except DRMError, e:
-          #TBI how to communicate the error
-          self.logger.error("!!!ERROR!!! %s:%s" %(type(e), e))
-      elif job.queue in self._pending_queues and \
-           job in self._pending_queues[job.queue]:
-        self._pending_queues[job.queue].remove(job)
-      job.status = constants.FAILED
-      job.exit_status = constants.USER_KILLED
-      job.exit_value = None
-      job.terminating_signal = None
-      job.str_rusage = None
+      with self._lock:
+        if job.drmaa_id:
+          self.logger.debug("Kill job " + repr(job_id) + " drmaa id: " + repr(job.drmaa_id) + " status " + repr(job.status))
+          try:
+            self._scheduler.kill_job(job.drmaa_id)
+          except DRMError, e:
+            #TBI how to communicate the error
+            self.logger.error("!!!ERROR!!! %s:%s" %(type(e), e))
+        elif job.queue in self._pending_queues and \
+            job in self._pending_queues[job.queue]:
+          self._pending_queues[job.queue].remove(job)
+        job.status = constants.FAILED
+        job.exit_status = constants.USER_KILLED
+        job.exit_value = None
+        job.terminating_signal = None
+        job.str_rusage = None
 
-      return True
+        return True
     
 
   def _stop_wf(self, wf_id):
@@ -621,7 +623,7 @@ class WorkflowEngine(RemoteFileController):
     
     
     try:
-      user_login = pwd.getpwuid(os.getuid())[0]
+      user_login = getpass.getuser()
     except Exception, e:
       raise EngineError("Couldn't identify user %s: %s \n" %(type(e), e))
     
@@ -790,12 +792,20 @@ class WorkflowEngine(RemoteFileController):
       self._database_server.delete_workflow(workflow_id)
       return True
     else:
+      (is_valid_wf, 
+      last_status_update) = self._database_server.is_valid_workflow(workflow_id, 
+                                                                  self._user_id)
+      if is_valid_wf and _out_to_date(last_status_update):
+        self.logger.critical("The workflow may not be properly deleted.")
+        self._database_server.delete_workflow(workflow_id)
+        return False
+      
       self._database_server.set_workflow_status(workflow_id, 
                                                 constants.DELETE_PENDING)
       if force and not self._wait_for_wf_deletion(workflow_id):
-       self.logger.critical("!! The workflow may not be properly deleted !!")
-       self._database_server.delete_workflow(workflow_id)
-       return False
+        self.logger.critical("The workflow may not be properly deleted.")
+        self._database_server.delete_workflow(workflow_id)
+        return False
       return True
 
 
