@@ -83,7 +83,8 @@ class EngineJob(Job):
                                     client_job.stdout_file,
                                     client_job.stderr_file ,
                                     client_job.working_directory ,
-                                    client_job.parallel_job_info)
+                                    client_job.parallel_job_info,
+                                    client_job.priority)
     
     self.job_id = -1
 
@@ -380,8 +381,7 @@ class EngineJob(Job):
     failed = (self.is_done() and \
               ((self.exit_value != 0 and self.exit_value != None) or \
               self.exit_status != constants.FINISHED_REGULARLY or \
-              self.terminating_signal != None)) or \
-             self.status == constants.WARNING
+              self.terminating_signal != None)) 
     return failed
 
   def ended_with_success(self):
@@ -450,6 +450,8 @@ class EngineWorkflow(Workflow):
     self.expiration_date = expiration_date
     self.name = name
 
+    self.user_storage = client_workflow.user_storage
+
     self.job_mapping = {}
     self.transfer_mapping = {}
     self._map()
@@ -633,7 +635,7 @@ class EngineWorkflow(Workflow):
     for job in to_abort:
       if job.job_id and job.status != constants.FAILED:
         #self.self.logger.debug("  ---- Failure: job to abort " + job.name)
-        assert(job.status == constants.NOT_SUBMITTED or job.status == constants.WARNING)
+        assert(job.status == constants.NOT_SUBMITTED)
         ended_jobs[job.job_id] = job
         job.status = constants.FAILED
         job.exit_status = constants.EXIT_ABORTED
@@ -653,15 +655,12 @@ class EngineWorkflow(Workflow):
 
     return (to_run, ended_jobs, status)
 
-  def restart(self, database_server):
-    assert(self.status == constants.WORKFLOW_DONE or self.status == constants.WARNING)
-    to_restart = False
-    undone_jobs = []
-   
+  
+  def _update_state_from_database_server(self, database_server):
     wf_status = database_server.get_detailed_workflow_status(self.wf_id)
 
     for job_info in wf_status[0]:
-      job_id, status, exit_info, date_info = job_info
+      job_id, status, queue, exit_info, date_info = job_info
       self.registered_jobs[job_id].status = status
       exit_status, exit_value, term_signal, resource_usage = exit_info
       self.registered_jobs[job_id].exit_status = exit_status
@@ -677,9 +676,49 @@ class EngineWorkflow(Workflow):
        transfer_type) = ft_info 
       self.registered_tr[engine_path].status = status
 
+    self.queue = wf_status[3]
+
+
+  def force_stop(self, database_server):
+    self._update_state_from_database_server(database_server)
+
+    new_status = {}
+    new_exit_info = {}
+
+    self.status = constants.WORKFLOW_DONE
+  
+    for client_job in self.jobs:
+      job = self.job_mapping[client_job]
+      if not job.is_done():
+        job.status = constants.FAILED
+        job.exit_status = constants.EXIT_ABORTED
+        job.exit_value = None
+        job.terminating_signal = None
+        job.drmaa_id = None
+        job.str_rusage = None
+        stdout = open(job.stdout_file, "w")
+        stdout.close()
+        stderr = open(job.stderr_file, "w")
+        stderr.close()
+        new_status[job.job_id] = constants.FAILED
+        new_exit_info[job.job_id] = job
+
+    database_server.set_jobs_status(new_status)
+    database_server.set_jobs_exit_info(new_exit_info)
+    database_server.set_workflow_status(self.wf_id, self.status)
+
+
+  def restart(self, database_server, queue):
+   
+    self._update_state_from_database_server(database_server)
+
+    self.queue = queue
+    to_restart = False
+    undone_jobs = []
     done = True
     sub_info_to_resert = {}
     new_status = {}
+    jobs_queue_changed = []
     for client_job in self.jobs:
       job = self.job_mapping[client_job]
       if job.failed():
@@ -689,6 +728,8 @@ class EngineWorkflow(Workflow):
         job.exit_value = None
         job.terminating_signal = None
         job.drmaa_id = None
+        job.queue = self.queue
+        jobs_queue_changed.append(job.job_id)
         stdout = open(job.stdout_file, "w")
         stdout.close()
         stderr = open(job.stderr_file, "w")
@@ -699,9 +740,12 @@ class EngineWorkflow(Workflow):
 
       if not job.ended_with_success():
         undone_jobs.append(job)
-
+        job.queue = self.queue
+        jobs_queue_changed.append(job.job_id)
+        
     database_server.set_submission_information(sub_info_to_resert, None)
     database_server.set_jobs_status(new_status)
+    database_server.set_queue(self.queue, jobs_queue_changed, self.wf_id)
 
     to_run = []
     if undone_jobs:
