@@ -1,5 +1,11 @@
 #!/usr/bin/env python
 
+'''
+@author: Soizic Laguitton
+@organization: U{IFR 49<http://www.ifr49.org>}
+@license: U{CeCILL version 2<http://www.cecill.info/licences/Licence_CeCILL_V2-en.html>}
+'''
+
 if __name__ == '__main__':
  
   import sys
@@ -30,7 +36,7 @@ if __name__ == '__main__':
   ressource_id = sys.argv[1]
   print "Ressource: " + ressource_id
 
-  config = Configuration(ressource_id)
+  config = Configuration.load_from_file(ressource_id)
 
   (server_log_file,
    server_log_format,
